@@ -1,7 +1,5 @@
 """ Macaulay2 Kernel for Jupyter
 """
 
-__version__ = '0.7.0'
-
 from .kernel import M2Kernel
-from .kernel import M2Interp
+from ._version import __version__
